Installation
------------

If you do not have a working Python 3.6 installation, consider installing Miniconda_.

Install scvelo from PyPI_ with (recommended)::

  pip install scvelo

or work with the latest version on GitHub_ by calling (after installing scanpy_)::

    git clone https://github.com/theislab/scvelo.git
    cd scvelo
    pip install .

.. _Miniconda: http://conda.pydata.org/miniconda.html
.. _PyPI: https://pypi.org/project/scvelo
.. _GitHub: https://github.com/theislab/scvelo
.. _scanpy: https://scanpy.readthedocs.io/en/latest/installation.html
